@@ -1,6 +1,7 @@
 #!/bin/sh
 
 name='arch'
+description='ArchWiki'
 path="$conf_sys_usr/share/doc/arch-wiki/html"
 
 available() {
@@ -9,15 +10,21 @@ available() {
 
 }
 
+describe() {
+
+	printf "%s\t%s\n" "$name" "$description"
+
+}
+
 info() {
 
 	if available; then
 		state="$(echo "$conf_sources" | grep -q "$name" && echo "+")"
 		count="$("$conf_find" "$path" -type f | wc -l | sed 's| ||g')"
-		printf '%-10s %3s %8i  %s\n' "$name" "$state" "$count" "$path"
+		printf '%-10s %-28s %3s %8i  %s\n' "$name" "$description" "$state" "$count" "$path"
 	else
 		state="$(echo "$conf_sources" | grep -q "$name" && echo "x")"
-		printf '%-12s %-11s (not installed)\n' "$name" "$state"
+		printf '%-10s %-30s %-11s (not installed)\n' "$name" "$description" "$state"
 	fi
 
 }
@@ -27,7 +34,7 @@ setup() {
 	results_title=''
 	results_text=''
 
-	langs="$(echo "$conf_wiki_lang" | awk -F ' ' '{
+	langs="$(echo "$conf_wiki_lang" | "$conf_awk" -F ' ' '{
 		for (i = 1; i <= NF; i++) {
 			lang = $i;
 			gsub(/[_-].*$/,"",lang);
@@ -46,12 +53,12 @@ setup() {
 
 	search_paths="$(
 		"$conf_find" "$path" -maxdepth 1 -mindepth 1 -type d -printf '%p\n' | \
-		awk "/$langs/"
+		"$conf_awk" "/$langs/"
 	)"
 
 	paths=''
 	for rg_l in $(echo "$langs" | sed 's|*|.*|g; s|\||\n|g'); do
-		p="$(echo "$search_paths" | awk "/$rg_l/ {printf(\"%s \",\$0)}")"
+		p="$(echo "$search_paths" | "$conf_awk" "/$rg_l/ {printf(\"%s \",\$0)}")"
 		if [ "$p" != '' ]; then
 			paths="$paths${paths:+$newline}$p"
 		else
@@ -60,7 +67,7 @@ setup() {
 		fi
 	done
 	paths="$(
-		echo "$paths" | sort | uniq | tr '\n' ' '
+		echo "$paths" | "$conf_sort" | uniq | tr '\n' ' '
 	)"
 
 	if [ "$(echo "$paths" | wc -w | sed 's| ||g')" = '0' ]; then
